@@ -1,5 +1,5 @@
 # ----------------------------------------------------------------------------
-# Copyright (c) 2016-2021, QIIME 2 development team.
+# Copyright (c) 2016-2022, QIIME 2 development team.
 #
 # Distributed under the terms of the Modified BSD License.
 #
@@ -7,10 +7,12 @@
 # ----------------------------------------------------------------------------
 
 from qiime2.plugin import (Plugin, Citations, Int, Range, Str, Choices, Bool,
-                           Float, List)
+                           Float, List, TypeMatch, Metadata)
 from q2_types.tree import Phylogeny, Unrooted, Rooted
 from q2_types.feature_data import FeatureData, AlignedSequence, Sequence
-from q2_types.feature_table import FeatureTable, Frequency
+from q2_types.feature_table import (FeatureTable, Frequency,
+                                    RelativeFrequency, PresenceAbsence,
+                                    Composition)
 from q2_types.distance_matrix import DistanceMatrix
 
 import q2_phylogeny
@@ -400,12 +402,14 @@ plugin.methods.register_function(
     deprecated=True
 )
 
+T1 = TypeMatch([Frequency, RelativeFrequency, PresenceAbsence])
+
 plugin.methods.register_function(
     function=q2_phylogeny.filter_table,
-    inputs={'table': FeatureTable[Frequency],
+    inputs={'table': FeatureTable[T1],
             'tree': Phylogeny[Rooted | Unrooted]},
     parameters={},
-    outputs=[('filtered_table', FeatureTable[Frequency])],
+    outputs=[('filtered_table', FeatureTable[T1])],
     input_descriptions={
         'table': 'Feature table that features should be filtered from.',
         'tree': ('Tree where tip identifiers are the feature identifiers that '
@@ -418,6 +422,41 @@ plugin.methods.register_function(
                  "are not tip identifiers in tree.")
 )
 
+T2 = TypeMatch([Rooted, Unrooted])
+
+T3 = (Frequency | RelativeFrequency | PresenceAbsence | Composition)
+
+plugin.methods.register_function(
+    function=q2_phylogeny.filter_tree,
+    inputs={'tree': Phylogeny[T2],
+            'table': FeatureTable[T3],
+            },
+    parameters={'metadata': Metadata,
+                'where': Str
+                },
+    outputs=[('filtered_tree', Phylogeny[T2])],
+    input_descriptions={
+        'tree': ('Tree that should be filtered'),
+        'table': ('Feature table which contains the identifier that should be'
+                  ' retained in the tree'),
+    },
+    parameter_descriptions={
+        'metadata': ("Feature metadata to use with the 'where' statement or "
+                     "to select tips to be retained. Metadata objects could "
+                     "also include FeatureData[Sequence] data types, if, for"
+                     "instance, you want to filter to match represenative "
+                     "sequencces."),
+        'where': ('SQLite WHERE clause specifying sample metadata criteria '
+                  'that must be met to be included in the filtered feature '
+                  'table. If not provided, all samples in `metadata` that'
+                  ' are also in the feature table will be retained.'),
+    },
+    output_descriptions={'filtered_tree': 'The resulting phylogenetic tree.'},
+    name="Remove features from tree based on metadata",
+    description=("Remove tips from a tree if their identifiers based on a "
+                 "set of provided identifiers.")
+)
+
 plugin.methods.register_function(
     function=q2_phylogeny.robinson_foulds,
     inputs={'trees': List[Phylogeny[Rooted | Unrooted]]},
